@@ -2,7 +2,7 @@
  * File: chat.c
  * Author: Justin Zaun
  * Project: GGZ GTK Client
- * $Id: chat.c 8543 2006-08-27 05:00:21Z jdorje $
+ * $Id: chat.c 9717 2008-02-14 17:51:52Z josef $
  *
  * This file contains all functions that are chat related.
  *
@@ -47,6 +47,11 @@
 #  include <winsock.h>
 #endif
 
+/* Supposedly not present on some systems (solaris). */
+#ifndef INADDR_NONE
+#  define INADDR_NONE ((unsigned long) -1)
+#endif
+
 #include <glib.h>
 
 #include "chat.h"
