@@ -2,7 +2,7 @@
  * File: client.h
  * Author: Justin Zaun
  * Project: GGZ GTK Client
- * $Id: client.h 7737 2006-01-06 22:34:17Z jdorje $
+ * $Id: client.h 8811 2007-01-04 22:39:18Z jdorje $
  *
  * This is the main program body for the GGZ client
  *
@@ -25,6 +25,9 @@
 
 #include <ggzcore.h>
 
+#ifndef __CLIENT_H__
+#define __CLIENT_H__
+
 void client_join_table(void);
 
 void client_start_table_join(void);
@@ -34,7 +37,22 @@ GtkWidget* create_win_main (void);
 /* Default font */
 #define DEFAULT_FONT "-*-fixed-medium-r-semicondensed--*-120-*-*-c-*-iso8859-1"
 
-extern GtkWidget *win_main;
+enum ggz_page {
+	GGZ_PAGE_FIRSTLOGIN,
+	GGZ_PAGE_LOGIN,
+	GGZ_PAGE_MAIN,
+	GGZ_PAGE_PROPS
+};
+
+void main_activate(void);
+
+extern GtkWidget *win_main; /* FIXME: not actually a window anymore. */
+extern GtkWidget *main_window;
+extern GtkWidget *ggznotebook;
 extern void (*connected_cb)(GGZServer *server);
 extern void (*launched_cb)(void);
-extern char *embedded_protocol_engine, *embedded_protocol_version;
+extern void (*ggz_closed_cb)(void);
+extern const char *embedded_protocol_engine, *embedded_protocol_version;
+extern const char *embedded_default_profile;
+
+#endif /* __CLIENT_H__ */
