@@ -3,7 +3,7 @@
  * Author: Brent Hendricks
  * Project: GGZ Text Client 
  * Date: 3/1/01
- * $Id: game.c 7753 2006-01-09 01:30:19Z jdorje $
+ * $Id: game.c 8705 2006-12-06 01:04:14Z jdorje $
  *
  * Functions for handling game events
  *
@@ -221,6 +221,8 @@ static GGZHookReturn game_launch_fail(GGZGameEvent id,
 {
 	chat_display_local(CHAT_LOCAL_HIGH, NULL, _("Launch failed"));
 
+	launch_dialog_close();
+
 	return GGZ_HOOK_OK;
 }
 
@@ -364,3 +366,18 @@ int game_initialize(int spectate)
 
 	return 0;
 }
+
+gboolean can_launch_gametype(GGZGameType *gt)
+{
+	const char *game = ggzcore_gametype_get_name(gt);
+	const char *engine = ggzcore_gametype_get_prot_engine(gt);
+	const char *version = ggzcore_gametype_get_prot_version(gt);
+	const int num = ggzcore_module_get_num_by_type(game, engine, version);
+
+	if (embedded_protocol_engine && embedded_protocol_version) {
+	  return (strcmp(engine, embedded_protocol_engine) == 0
+		  && strcmp(version, embedded_protocol_version) == 0);
+	} else {
+	  return (num > 0);
+	}
+}
