@@ -2,7 +2,7 @@
  * File: ggz-gtk.h
  * Author: Jason Short
  * Project: GGZ GTK Client Library
- * $Id: client.h 7735 2006-01-06 08:27:50Z jdorje $
+ * $Id: ggz-gtk.h 8452 2006-08-01 19:53:36Z jdorje $
  *
  * This library provides interface functions so external programs can embed
  * GGZ via a GTK interface
@@ -31,9 +31,9 @@
 void ggz_gtk_initialize(gboolean reconnect,
 			void (*connected)(GGZServer *server),
 			void (*launched)(void),
-			char *protocol_engine,
-			char *protocol_version);
+			void (*ggz_closed)(void),
+			const char *protocol_engine,
+			const char *protocol_version,
+			const char *default_profile);
 
-void ggz_gtk_login_raise(const char *default_profile);
-
-GtkWidget *ggz_gtk_create_main_area(GtkWidget *main_win);
+GtkWidget *ggz_gtk_create_main_area(GtkWidget *main_window);
