@@ -2,7 +2,7 @@
  * File: ggzclient.c
  * Author: Justin Zaun
  * Project: GGZ GTK Client
- * $Id: ggzclient.c 7767 2006-01-11 18:15:47Z jdorje $
+ * $Id: ggzclient.c 8763 2006-12-27 10:02:33Z jdorje $
  *
  * This is the main program body for the GGZ client
  *
@@ -39,6 +39,7 @@
 #include "chat.h"
 #include "client.h"
 #include "game.h"
+#include "ggz-gtk.h"
 #include "ggzclient.h"
 #include "launch.h"
 #include "login.h"
@@ -160,8 +161,41 @@ static GGZHookReturn ggz_auto_join(GGZServerEvent id,
 				   const void *event_data,
 				   const void *user_data)
 {
-	ggzcore_server_join_room(server, 0);
-	select_room(ggzcore_server_get_nth_room(server, 0));
+	int i;
+	const int numrooms = ggzcore_server_get_num_rooms(server);
+	GGZRoom *lobby = NULL, *supported = NULL, *joinroom = NULL;
+
+	for (i = 0; i < numrooms; i++) {
+		GGZRoom *room = ggzcore_server_get_nth_room(server, i);
+		GGZGameType *gt = ggzcore_room_get_gametype(room);
+
+		if (ggzcore_room_get_closed(room)) {
+			continue;
+		}
+		if (!gt) {
+			lobby = room;
+		} else if (can_launch_gametype(gt)) {
+			supported = room;
+		}
+	}
+
+	if (embedded_protocol_engine && supported) {
+		joinroom = supported;
+		/* For embedded GGZ:
+		   first choice is to join a supported room. */
+	} else if (lobby) {
+		joinroom = lobby;
+		/* First choice: join the lobby. */
+	} else if (supported) {
+		joinroom = supported;
+		/* Second choice: join a supported room. */
+	} else {
+		return GGZ_HOOK_REMOVE;
+		/* Otherwise: don't join any room */
+	}
+
+	ggzcore_server_join_room(server, joinroom);
+	select_room(joinroom);
 
 	return GGZ_HOOK_REMOVE;
 }
@@ -185,15 +219,15 @@ static GGZHookReturn ggz_logged_in(GGZServerEvent id,
 		title = g_strdup_printf("GGZ Gaming Zone - [%s:%d]",
 					ggzcore_server_get_host(server),
 					ggzcore_server_get_port(server));
-		gtk_window_set_title(GTK_WINDOW(win_main), title);
+		gtk_window_set_title(GTK_WINDOW(main_window), title);
 		g_free(title);
 	}
 
-	login_destroy();
+	main_activate();
 	ggzcore_server_add_event_hook(server, GGZ_ROOM_LIST,
 				      ggz_auto_join);
-	ggzcore_server_list_rooms(server, -1, 1);
 	ggzcore_server_list_gametypes(server, 1);
+	ggzcore_server_list_rooms(server, -1, 1);
 
 
 	/* If this was a first-time login, get the password from the server */
@@ -222,12 +256,10 @@ static GGZHookReturn ggz_login_fail(GGZServerEvent id,
 	return GGZ_HOOK_OK;
 }
 
-static void client_update_one_room(int room)
+static void client_update_one_room(const GGZRoom *room)
 {
-	GGZRoom *roomptr = ggzcore_server_get_nth_room(server, room);
-
-	if (roomptr) {
-		update_one_room(roomptr);
+	if (room) {
+		update_one_room(room);
 	}
 }
 
@@ -235,7 +267,7 @@ static GGZHookReturn ggz_num_players_changed(GGZServerEvent id,
 					     const void *event_data,
 					     const void *user_data)
 {
-	GtkWidget *serverbar = lookup_widget(win_main, "serverbar");
+	GtkWidget *serverbar = ggz_lookup_widget(win_main, "serverbar");
 	guint context;
 	int players = ggzcore_server_get_num_players(server);
 	char buf[128];
@@ -249,6 +281,14 @@ static GGZHookReturn ggz_num_players_changed(GGZServerEvent id,
 	return GGZ_HOOK_OK;
 }
 
+static GGZHookReturn ggz_num_rooms_changed(GGZServerEvent id,
+					     const void *event_data,
+					     const void *user_data)
+{
+	update_room_list();
+	return GGZ_HOOK_OK;
+}
+
 static GGZHookReturn ggz_entered(GGZServerEvent id, const void *event_data,
 				 const void *user_data)
 {
@@ -275,7 +315,7 @@ static GGZHookReturn ggz_entered(GGZServerEvent id, const void *event_data,
 
 
 	/* Set the room label to current room */
-	tmp = lookup_widget(win_main, "Current_room_label");
+	tmp = ggz_lookup_widget(win_main, "Current_room_label");
 	name =
 	    g_strdup_printf(_("Current Room: %s"),
 			    ggzcore_room_get_name
@@ -299,27 +339,27 @@ static GGZHookReturn ggz_entered(GGZServerEvent id, const void *event_data,
 	gt = ggzcore_room_get_gametype(room);
 
 	if (ggzcore_gametype_get_name(gt) == NULL) {
-		tmp = lookup_widget(win_main, "table_vpaned");
+		tmp = ggz_lookup_widget(win_main, "table_vpaned");
 		if (GTK_PANED(tmp)->child1_size != 0)
 			g_object_set(G_OBJECT(tmp), "user_data",
 				     GTK_PANED(tmp)->child1_size, NULL);
 		gtk_paned_set_position(GTK_PANED(tmp), 0);
-		tmp = lookup_widget(win_main, "launch_button");
+		tmp = ggz_lookup_widget(win_main, "launch_button");
 		gtk_widget_set_sensitive(tmp, FALSE);
-		tmp = lookup_widget(win_main, "join_button");
+		tmp = ggz_lookup_widget(win_main, "join_button");
 		gtk_widget_set_sensitive(tmp, FALSE);
-		tmp = lookup_widget(win_main, "watch_button");
+		tmp = ggz_lookup_widget(win_main, "watch_button");
 		gtk_widget_set_sensitive(tmp, FALSE);
 	} else {
 		int height;
-		tmp = lookup_widget(win_main, "table_vpaned");
+		tmp = ggz_lookup_widget(win_main, "table_vpaned");
 		g_object_get(G_OBJECT(tmp), "user_data", &height, NULL);
 		gtk_paned_set_position(GTK_PANED(tmp), height);
-		tmp = lookup_widget(win_main, "launch_button");
+		tmp = ggz_lookup_widget(win_main, "launch_button");
 		gtk_widget_set_sensitive(tmp, TRUE);
-		tmp = lookup_widget(win_main, "join_button");
+		tmp = ggz_lookup_widget(win_main, "join_button");
 		gtk_widget_set_sensitive(tmp, TRUE);
-		tmp = lookup_widget(win_main, "watch_button");
+		tmp = ggz_lookup_widget(win_main, "watch_button");
 		gtk_widget_set_sensitive(tmp, TRUE);
 	}
 
@@ -355,7 +395,10 @@ static GGZHookReturn ggz_logout(GGZServerEvent id, const void *event_data,
 	}
 
 	/* set title */
-	gtk_window_set_title(GTK_WINDOW(win_main), "GGZ Gaming Zone");
+	if (!embedded_protocol_version) {
+		gtk_window_set_title(GTK_WINDOW(main_window),
+				     _("GGZ Gaming Zone"));
+	}
 
 	return GGZ_HOOK_OK;
 }
@@ -422,11 +465,18 @@ static GGZHookReturn ggz_list_players(GGZRoomEvent id,
 				      const void *event_data,
 				      const void *user_data)
 {
-	const int *room = event_data;
+	const GGZRoom *room = event_data;
 
 	update_player_list();
-	if (room)
-		client_update_one_room(*room);
+	client_update_one_room(room);
+	return GGZ_HOOK_OK;
+}
+
+static GGZHookReturn ggz_info_player(GGZRoomEvent id,
+				     const void *event_data,
+				     const void *user_data)
+{
+	update_player_list();
 	return GGZ_HOOK_OK;
 }
 
@@ -434,9 +484,9 @@ static GGZHookReturn ggz_player_count(GGZRoomEvent id,
 				      const void *event_data,
 				      const void *user_data)
 {
-	const int *room = event_data;
+	const GGZRoom *room = event_data;
 
-	client_update_one_room(*room);
+	client_update_one_room(room);
 	return GGZ_HOOK_OK;
 }
 
@@ -449,7 +499,7 @@ static GGZHookReturn ggz_room_enter(GGZRoomEvent id,
 	client_update_one_room(data->to_room);
 	client_update_one_room(data->from_room);
 	update_player_list();
-	chat_enter(data->player_name, data->from_room);
+	chat_enter(data->player_name, data->rooms_known, data->from_room);
 
 	return GGZ_HOOK_OK;
 }
@@ -464,7 +514,7 @@ static GGZHookReturn ggz_room_leave(GGZRoomEvent id,
 	client_update_one_room(data->to_room);
 	client_update_one_room(data->from_room);
 	update_player_list();
-	chat_part(data->player_name, data->to_room);
+	chat_part(data->player_name, data->rooms_known, data->to_room);
 
 	return GGZ_HOOK_OK;
 }
@@ -647,9 +697,11 @@ static GGZHookReturn ggz_room_list(GGZServerEvent id,
 		ggzcore_room_add_event_hook(room, GGZ_TABLE_UPDATE,
 					    ggz_table_update);
 		ggzcore_room_add_event_hook(room, GGZ_PLAYER_LAG,
-					    ggz_list_players);
+					    ggz_info_player);
+		ggzcore_room_add_event_hook(room, GGZ_PLAYER_PERMS,
+					    ggz_info_player);
 		ggzcore_room_add_event_hook(room, GGZ_PLAYER_STATS,
-					    ggz_list_players);
+					    ggz_info_player);
 	}
 
 	return GGZ_HOOK_OK;
@@ -664,7 +716,7 @@ void ggz_sensitivity_init(void)
 	/* Menu bar */
 
 	/* Set the room label to current room */
-	tmp = lookup_widget(win_main, "Current_room_label");
+	tmp = ggz_lookup_widget(win_main, "Current_room_label");
 	gtk_label_set_text(GTK_LABEL(tmp), _("Current Room:"));
 }
 
@@ -733,7 +785,7 @@ static GGZHookReturn ggz_state_change(GGZServerEvent id,
 		break;
 	}
 
-	statebar = lookup_widget(win_main, "statebar");
+	statebar = ggz_lookup_widget(win_main, "statebar");
 	context =
 	    gtk_statusbar_get_context_id(GTK_STATUSBAR(statebar), "state");
 	gtk_statusbar_pop(GTK_STATUSBAR(statebar), context);
@@ -758,41 +810,41 @@ static GGZHookReturn ggz_state_sensitivity(GGZServerEvent id,
 		/* Re-enable connect button */
 		if (login_dialog) {
 			tmp =
-			    lookup_widget(login_dialog, "connect_button");
+			    ggz_lookup_widget(login_dialog, "connect_button");
 			gtk_widget_set_sensitive(tmp, TRUE);
 		}
 
 		/* Menu bar */
-		tmp = lookup_widget(win_main, "connect");
+		tmp = ggz_lookup_widget(win_main, "connect");
 		gtk_widget_set_sensitive(tmp, TRUE);
 
-		tmp = lookup_widget(win_main, "disconnect");
+		tmp = ggz_lookup_widget(win_main, "disconnect");
 		gtk_widget_set_sensitive(tmp, FALSE);
 
-		tmp = lookup_widget(win_main, "game");
+		tmp = ggz_lookup_widget(win_main, "game");
 		gtk_widget_set_sensitive(tmp, FALSE);
 
-		tmp = lookup_widget(win_main, "view");
+		tmp = ggz_lookup_widget(win_main, "view");
 		gtk_widget_set_sensitive(tmp, FALSE);
 
 		/* Tool bar */
-		tmp = lookup_widget(win_main, "disconnect_button");
+		tmp = ggz_lookup_widget(win_main, "disconnect_button");
 		gtk_widget_set_sensitive(tmp, FALSE);
 
-		tmp = lookup_widget(win_main, "launch_button");
+		tmp = ggz_lookup_widget(win_main, "launch_button");
 		gtk_widget_set_sensitive(tmp, FALSE);
 
-		tmp = lookup_widget(win_main, "join_button");
+		tmp = ggz_lookup_widget(win_main, "join_button");
 		gtk_widget_set_sensitive(tmp, FALSE);
 
-		tmp = lookup_widget(win_main, "watch_button");
+		tmp = ggz_lookup_widget(win_main, "watch_button");
 		gtk_widget_set_sensitive(tmp, FALSE);
 
-		tmp = lookup_widget(win_main, "leave_button");
+		tmp = ggz_lookup_widget(win_main, "leave_button");
 		gtk_widget_set_sensitive(tmp, FALSE);
 
 #ifdef STATS_BUTTON
-		tmp = lookup_widget(win_main, "stats_button");
+		tmp = ggz_lookup_widget(win_main, "stats_button");
 		gtk_widget_set_sensitive(tmp, FALSE);
 #endif
 
@@ -801,10 +853,10 @@ static GGZHookReturn ggz_state_sensitivity(GGZServerEvent id,
 		sensitize_player_list(FALSE);
 		sensitize_table_list(FALSE);
 
-		tmp = lookup_widget(win_main, "chat_entry");
+		tmp = ggz_lookup_widget(win_main, "chat_entry");
 		gtk_widget_set_sensitive(tmp, FALSE);
 
-		tmp = lookup_widget(win_main, "send_button");
+		tmp = ggz_lookup_widget(win_main, "send_button");
 		gtk_widget_set_sensitive(tmp, FALSE);
 		break;
 
@@ -812,19 +864,19 @@ static GGZHookReturn ggz_state_sensitivity(GGZServerEvent id,
 		if (login_dialog) {
 			/* Desensitize the connect button */
 			tmp =
-			    lookup_widget(login_dialog, "connect_button");
+			    ggz_lookup_widget(login_dialog, "connect_button");
 			gtk_widget_set_sensitive(tmp, FALSE);
 		}
 
 		/* Menu bar */
-		tmp = lookup_widget(win_main, "connect");
+		tmp = ggz_lookup_widget(win_main, "connect");
 		gtk_widget_set_sensitive(tmp, FALSE);
 
-		tmp = lookup_widget(win_main, "disconnect");
+		tmp = ggz_lookup_widget(win_main, "disconnect");
 		gtk_widget_set_sensitive(tmp, TRUE);
 
 		/* Tool bar */
-		tmp = lookup_widget(win_main, "disconnect_button");
+		tmp = ggz_lookup_widget(win_main, "disconnect_button");
 		gtk_widget_set_sensitive(tmp, TRUE);
 		break;
 
@@ -835,7 +887,7 @@ static GGZHookReturn ggz_state_sensitivity(GGZServerEvent id,
 		if (login_dialog) {
 			/* Desensitize the connect button */
 			tmp =
-			    lookup_widget(login_dialog, "connect_button");
+			    ggz_lookup_widget(login_dialog, "connect_button");
 			gtk_widget_set_sensitive(tmp, FALSE);
 		}
 
@@ -844,12 +896,12 @@ static GGZHookReturn ggz_state_sensitivity(GGZServerEvent id,
 	case GGZ_STATE_LOGGED_IN:
 		/* set senditivity */
 		/* Menu bar */
-		tmp = lookup_widget(win_main, "view");
+		tmp = ggz_lookup_widget(win_main, "view");
 		gtk_widget_set_sensitive(tmp, TRUE);
 
 		/* Tool bar */
 #ifdef STATS_BUTTON
-		tmp = lookup_widget(win_main, "stats_button");
+		tmp = ggz_lookup_widget(win_main, "stats_button");
 		gtk_widget_set_sensitive(tmp, TRUE);
 #endif
 
@@ -859,32 +911,32 @@ static GGZHookReturn ggz_state_sensitivity(GGZServerEvent id,
 
 	case GGZ_STATE_BETWEEN_ROOMS:
 	case GGZ_STATE_ENTERING_ROOM:
-		tmp = lookup_widget(win_main, "chat_entry");
+		tmp = ggz_lookup_widget(win_main, "chat_entry");
 		gtk_widget_set_sensitive(tmp, FALSE);
 
-		tmp = lookup_widget(win_main, "send_button");
+		tmp = ggz_lookup_widget(win_main, "send_button");
 		gtk_widget_set_sensitive(tmp, FALSE);
 		break;
 
 	case GGZ_STATE_IN_ROOM:
 		/* Menu bar */
-		tmp = lookup_widget(win_main, "game");
+		tmp = ggz_lookup_widget(win_main, "game");
 		gtk_widget_set_sensitive(tmp, TRUE);
 
-		tmp = lookup_widget(win_main, "launch");
+		tmp = ggz_lookup_widget(win_main, "launch");
 		gtk_widget_set_sensitive(tmp, TRUE);
 
-		tmp = lookup_widget(win_main, "join");
+		tmp = ggz_lookup_widget(win_main, "join");
 		gtk_widget_set_sensitive(tmp, TRUE);
 
 		/* Tool bar */
-		tmp = lookup_widget(win_main, "launch_button");
+		tmp = ggz_lookup_widget(win_main, "launch_button");
 		gtk_widget_set_sensitive(tmp, TRUE);
 
-		tmp = lookup_widget(win_main, "join_button");
+		tmp = ggz_lookup_widget(win_main, "join_button");
 		gtk_widget_set_sensitive(tmp, TRUE);
 
-		tmp = lookup_widget(win_main, "watch_button");
+		tmp = ggz_lookup_widget(win_main, "watch_button");
 		gtk_widget_set_sensitive(tmp, TRUE);
 
 		/* Client area */
@@ -892,100 +944,100 @@ static GGZHookReturn ggz_state_sensitivity(GGZServerEvent id,
 		sensitize_player_list(TRUE);
 		sensitize_table_list(TRUE);
 
-		tmp = lookup_widget(win_main, "chat_entry");
+		tmp = ggz_lookup_widget(win_main, "chat_entry");
 		gtk_widget_set_sensitive(tmp, TRUE);
 
-		tmp = lookup_widget(win_main, "send_button");
+		tmp = ggz_lookup_widget(win_main, "send_button");
 		gtk_widget_set_sensitive(tmp, TRUE);
 		break;
 
 	case GGZ_STATE_LAUNCHING_TABLE:
 		/* Tool bar */
-		tmp = lookup_widget(win_main, "launch_button");
+		tmp = ggz_lookup_widget(win_main, "launch_button");
 		gtk_widget_set_sensitive(tmp, FALSE);
 
-		tmp = lookup_widget(win_main, "join_button");
+		tmp = ggz_lookup_widget(win_main, "join_button");
 		gtk_widget_set_sensitive(tmp, FALSE);
 
-		tmp = lookup_widget(win_main, "watch_button");
+		tmp = ggz_lookup_widget(win_main, "watch_button");
 		gtk_widget_set_sensitive(tmp, FALSE);
 
 		/* Menu bar */
-		tmp = lookup_widget(win_main, "launch");
+		tmp = ggz_lookup_widget(win_main, "launch");
 		gtk_widget_set_sensitive(tmp, FALSE);
 
-		tmp = lookup_widget(win_main, "join");
+		tmp = ggz_lookup_widget(win_main, "join");
 		gtk_widget_set_sensitive(tmp, FALSE);
 		break;
 
 	case GGZ_STATE_JOINING_TABLE:
 		/* Tool bar */
-		tmp = lookup_widget(win_main, "launch_button");
+		tmp = ggz_lookup_widget(win_main, "launch_button");
 		gtk_widget_set_sensitive(tmp, FALSE);
 
-		tmp = lookup_widget(win_main, "join_button");
+		tmp = ggz_lookup_widget(win_main, "join_button");
 		gtk_widget_set_sensitive(tmp, FALSE);
 
-		tmp = lookup_widget(win_main, "watch_button");
+		tmp = ggz_lookup_widget(win_main, "watch_button");
 		gtk_widget_set_sensitive(tmp, FALSE);
 
 		/* Menu bar */
-		tmp = lookup_widget(win_main, "launch");
+		tmp = ggz_lookup_widget(win_main, "launch");
 		gtk_widget_set_sensitive(tmp, FALSE);
 
-		tmp = lookup_widget(win_main, "join");
+		tmp = ggz_lookup_widget(win_main, "join");
 		gtk_widget_set_sensitive(tmp, FALSE);
 		break;
 
 	case GGZ_STATE_AT_TABLE:
 		/* Tool bar */
-		tmp = lookup_widget(win_main, "leave_button");
+		tmp = ggz_lookup_widget(win_main, "leave_button");
 		gtk_widget_set_sensitive(tmp, TRUE);
 
 		/* Menu bar */
-		tmp = lookup_widget(win_main, "leave");
+		tmp = ggz_lookup_widget(win_main, "leave");
 		gtk_widget_set_sensitive(tmp, TRUE);
 		break;
 
 	case GGZ_STATE_LEAVING_TABLE:
 		/* Tool bar */
-		tmp = lookup_widget(win_main, "leave_button");
+		tmp = ggz_lookup_widget(win_main, "leave_button");
 		gtk_widget_set_sensitive(tmp, FALSE);
 
 		/* Menu bar */
-		tmp = lookup_widget(win_main, "leave");
+		tmp = ggz_lookup_widget(win_main, "leave");
 		gtk_widget_set_sensitive(tmp, FALSE);
 		break;
 
 	case GGZ_STATE_LOGGING_OUT:
 		/* Menu bar */
-		tmp = lookup_widget(win_main, "disconnect");
+		tmp = ggz_lookup_widget(win_main, "disconnect");
 		gtk_widget_set_sensitive(tmp, FALSE);
 
-		tmp = lookup_widget(win_main, "game");
+		tmp = ggz_lookup_widget(win_main, "game");
 		gtk_widget_set_sensitive(tmp, FALSE);
 
-		tmp = lookup_widget(win_main, "view");
+		tmp = ggz_lookup_widget(win_main, "view");
 		gtk_widget_set_sensitive(tmp, FALSE);
 
 		/* Tool bar */
-		tmp = lookup_widget(win_main, "disconnect_button");
+		tmp = ggz_lookup_widget(win_main, "disconnect_button");
 		gtk_widget_set_sensitive(tmp, FALSE);
 
-		tmp = lookup_widget(win_main, "launch_button");
+		tmp = ggz_lookup_widget(win_main, "launch_button");
 		gtk_widget_set_sensitive(tmp, FALSE);
 
-		tmp = lookup_widget(win_main, "join_button");
+		tmp = ggz_lookup_widget(win_main, "join_button");
 		gtk_widget_set_sensitive(tmp, FALSE);
 
-		tmp = lookup_widget(win_main, "watch_button");
+		tmp = ggz_lookup_widget(win_main, "watch_button");
 		gtk_widget_set_sensitive(tmp, FALSE);
 
-		tmp = lookup_widget(win_main, "leave_button");
+		tmp = ggz_lookup_widget(win_main, "leave_button");
 		gtk_widget_set_sensitive(tmp, FALSE);
 
 #ifdef STATS_BUTTON
-		tmp = lookup_widget(win_main, "stats_button");
+		tmp = ggz_lookup_widget(win_main, "stats_button");
 		gtk_widget_set_sensitive(tmp, FALSE);
 #endif
 
@@ -994,10 +1046,10 @@ static GGZHookReturn ggz_state_sensitivity(GGZServerEvent id,
 		sensitize_player_list(FALSE);
 		sensitize_table_list(FALSE);
 
-		tmp = lookup_widget(win_main, "chat_entry");
+		tmp = ggz_lookup_widget(win_main, "chat_entry");
 		gtk_widget_set_sensitive(tmp, FALSE);
 
-		tmp = lookup_widget(win_main, "send_button");
+		tmp = ggz_lookup_widget(win_main, "send_button");
 		gtk_widget_set_sensitive(tmp, FALSE);
 		break;
 	}
@@ -1114,6 +1166,7 @@ void server_disconnect(void)
 
 	chat_display_local(CHAT_LOCAL_HIGH, NULL,
 			   _("Disconnected from server."));
+	main_activate();
 	if (connected_cb) {
 		connected_cb(NULL);
 	}
@@ -1142,6 +1195,8 @@ void ggz_event_init(GGZServer * Server)
 	/* Unused: GGZ_TYPE_LIST */
 	ggzcore_server_add_event_hook(Server, GGZ_SERVER_PLAYERS_CHANGED,
 				      ggz_num_players_changed);
+	ggzcore_server_add_event_hook(Server, GGZ_SERVER_ROOMS_CHANGED,
+				      ggz_num_rooms_changed);
 	ggzcore_server_add_event_hook(Server, GGZ_ENTERED, ggz_entered);
 	ggzcore_server_add_event_hook(Server,
 				      GGZ_ENTER_FAIL, ggz_entered_fail);
