@@ -2,7 +2,7 @@
  * File: playerinfo.c
  * Author: Justin Zaun
  * Project: GGZ GTK Client
- * $Id: playerinfo.c 7718 2006-01-03 06:48:59Z jdorje $
+ * $Id: playerinfo.c 8771 2006-12-28 09:28:29Z jdorje $
  *
  * This dialog is used to display information about a selected player to
  * the user. 
@@ -39,6 +39,8 @@
 #include <ggzcore.h>
 
 #include "chat.h"
+#include "client.h"
+#include "ggzutils.h"
 #include "playerinfo.h"
 #include "support.h"
 
@@ -87,6 +89,8 @@ static GtkWidget *create_dlg_info(GGZServer *server)
 	GtkWidget *table;
 	GtkWidget *type_label;
 	GtkWidget *type;
+	GtkWidget *perms_label;
+	GtkWidget *perms;
 	GtkWidget *record_label;
 	GtkWidget *record;
 	GtkWidget *rating_label;
@@ -99,7 +103,7 @@ static GtkWidget *create_dlg_info(GGZServer *server)
 	GtkWidget *chat;
 
 	dlg_info = gtk_dialog_new_with_buttons(_("Player Information"),
-					       GTK_WINDOW(win_main), 0,
+					       GTK_WINDOW(main_window), 0,
 					       GTK_STOCK_CLOSE,
 					       GTK_RESPONSE_CLOSE, NULL);
 	g_object_set_data(G_OBJECT(dlg_info), "dlg_info", dlg_info);
@@ -108,7 +112,7 @@ static GtkWidget *create_dlg_info(GGZServer *server)
 	g_object_set_data(G_OBJECT(dlg_info), "dialog_vbox", dialog_vbox);
 	gtk_widget_show(dialog_vbox);
 
-	display_table = gtk_table_new(8, 3, FALSE);
+	display_table = gtk_table_new(9, 3, FALSE);
 	gtk_widget_ref(display_table);
 	g_object_set_data_full(G_OBJECT(dlg_info), "display_table",
 			       display_table,
@@ -182,6 +186,18 @@ static GtkWidget *create_dlg_info(GGZServer *server)
 			 2, 3, 2, 3, GTK_EXPAND, 0, 0, 0);
 	gtk_label_set_line_wrap(GTK_LABEL(type), TRUE);
 
+	/* Add permissions label */
+	perms_label = gtk_label_new(_("Permissions:"));
+	gtk_widget_show(perms_label);
+	gtk_table_attach(GTK_TABLE(display_table), perms_label,
+			 1, 2, 3, 4, 0, 0, 0, 0);
+	perms = gtk_label_new("");
+	gtk_widget_show(perms);
+	gtk_table_attach(GTK_TABLE(display_table), perms,
+			 2, 3, 3, 4, GTK_EXPAND, 0, 0, 0);
+	g_object_set_data(G_OBJECT(dlg_info), "perms", perms);
+	gtk_label_set_line_wrap(GTK_LABEL(perms), TRUE);
+
 	/* Add "Record" label */
 	record_label = gtk_label_new(_("Record:"));
 	gtk_widget_ref(record_label);
@@ -190,7 +206,7 @@ static GtkWidget *create_dlg_info(GGZServer *server)
 			       (GtkDestroyNotify) gtk_widget_unref);
 	/* gtk_widget_show is called later. */
 	gtk_table_attach(GTK_TABLE(display_table), record_label,
-			 1, 2, 3, 4, 0, 0, 0, 0);
+			 1, 2, 4, 5, 0, 0, 0, 0);
 
 	record = gtk_label_new("");
 	gtk_widget_ref(record);
@@ -198,7 +214,7 @@ static GtkWidget *create_dlg_info(GGZServer *server)
 			       (GtkDestroyNotify) gtk_widget_unref);
 	/* gtk_widget_show is called later. */
 	gtk_table_attach(GTK_TABLE(display_table), record,
-			 2, 3, 3, 4, GTK_EXPAND, 0, 0, 0);
+			 2, 3, 4, 5, GTK_EXPAND, 0, 0, 0);
 
 	/* Add "Rating" label */
 	rating_label = gtk_label_new(_("Rating:"));
@@ -208,7 +224,7 @@ static GtkWidget *create_dlg_info(GGZServer *server)
 			       (GtkDestroyNotify) gtk_widget_unref);
 	/* gtk_widget_show is called later. */
 	gtk_table_attach(GTK_TABLE(display_table), rating_label,
-			 1, 2, 4, 5, 0, 0, 0, 0);
+			 1, 2, 5, 6, 0, 0, 0, 0);
 
 	rating = gtk_label_new("");
 	gtk_widget_ref(rating);
@@ -216,7 +232,7 @@ static GtkWidget *create_dlg_info(GGZServer *server)
 			       (GtkDestroyNotify) gtk_widget_unref);
 	/* gtk_widget_show is called later. */
 	gtk_table_attach(GTK_TABLE(display_table), rating,
-			 2, 3, 4, 5, GTK_EXPAND, 0, 0, 0);
+			 2, 3, 5, 6, GTK_EXPAND, 0, 0, 0);
 
 	/* Add "Ranking" label */
 	ranking_label = gtk_label_new(_("Rank:"));
@@ -226,7 +242,7 @@ static GtkWidget *create_dlg_info(GGZServer *server)
 			       (GtkDestroyNotify) gtk_widget_unref);
 	/* gtk_widget_show is called later. */
 	gtk_table_attach(GTK_TABLE(display_table), ranking_label,
-			 1, 2, 5, 6, 0, 0, 0, 0);
+			 1, 2, 6, 7, 0, 0, 0, 0);
 
 	ranking = gtk_label_new("");
 	gtk_widget_ref(ranking);
@@ -234,7 +250,7 @@ static GtkWidget *create_dlg_info(GGZServer *server)
 			       (GtkDestroyNotify) gtk_widget_unref);
 	/* gtk_widget_show is called later. */
 	gtk_table_attach(GTK_TABLE(display_table), ranking,
-			 2, 3, 5, 6, GTK_EXPAND, 0, 0, 0);
+			 2, 3, 6, 7, GTK_EXPAND, 0, 0, 0);
 
 	/* Add "Highscore" label */
 	highscore_label = gtk_label_new(_("Score:"));
@@ -244,7 +260,7 @@ static GtkWidget *create_dlg_info(GGZServer *server)
 			       (GtkDestroyNotify) gtk_widget_unref);
 	/* gtk_widget_show is called later. */
 	gtk_table_attach(GTK_TABLE(display_table), highscore_label,
-			 1, 2, 6, 7, 0, 0, 0, 0);
+			 1, 2, 7, 8, 0, 0, 0, 0);
 
 	highscore = gtk_label_new("");
 	gtk_widget_ref(highscore);
@@ -252,7 +268,7 @@ static GtkWidget *create_dlg_info(GGZServer *server)
 			       (GtkDestroyNotify) gtk_widget_unref);
 	/* gtk_widget_show is called later. */
 	gtk_table_attach(GTK_TABLE(display_table), highscore,
-			 2, 3, 6, 7, GTK_EXPAND, 0, 0, 0);
+			 2, 3, 7, 8, GTK_EXPAND, 0, 0, 0);
 
 	/* Add "Private chat" label */
 	chat_label = gtk_label_new(_("Message:"));
@@ -262,7 +278,7 @@ static GtkWidget *create_dlg_info(GGZServer *server)
 			       (GtkDestroyNotify) gtk_widget_unref);
 	gtk_widget_show(chat_label);
 	gtk_table_attach(GTK_TABLE(display_table), chat_label,
-			 1, 2, 7, 8, 0, 0, 0, 0);
+			 1, 2, 8, 9, 0, 0, 0, 0);
 
 	chat = gtk_entry_new();
 	gtk_widget_ref(chat);
@@ -270,7 +286,7 @@ static GtkWidget *create_dlg_info(GGZServer *server)
 			       (GtkDestroyNotify) gtk_widget_unref);
 	gtk_widget_show(chat);
 	gtk_table_attach(GTK_TABLE(display_table), chat,
-			 2, 3, 7, 8, GTK_EXPAND, 0, 0, 0);
+			 2, 3, 8, 9, GTK_EXPAND, 0, 0, 0);
 	g_signal_connect(chat, "activate",
 			 GTK_SIGNAL_FUNC(chat_activate), server);
 
@@ -297,11 +313,12 @@ void player_info_create_or_raise(GGZPlayer *player)
 	GGZRoom *room = ggzcore_player_get_room(player);
 	GGZTable *table = ggzcore_player_get_table(player);
 	GGZServer *server = ggzcore_room_get_server(room);
-	char text[128];
+	char text[1024];
 	char *ptype = _("Unknown");
 	int wins, losses, ties, forfeits;
 	int rating, ranking;
 	int highscore;
+	GGZPerm p;
 
 	if (!dialog) {
 		dialog = create_dlg_info(server);
@@ -338,6 +355,9 @@ void player_info_create_or_raise(GGZPlayer *player)
 	case GGZ_PLAYER_GUEST:
 		ptype = _("Guest");
 		break;
+	case GGZ_PLAYER_HOST:
+		ptype = _("Host");
+		break;
 	case GGZ_PLAYER_ADMIN:
 		ptype = _("Administrator");
 		break;
@@ -347,6 +367,22 @@ void player_info_create_or_raise(GGZPlayer *player)
 	}
 	gtk_label_set_text(GTK_LABEL(tmp), ptype);
 
+	tmp = g_object_get_data(G_OBJECT(dialog), "perms");
+	text[0] = '\0';
+	for (p = 0; p < GGZ_PERM_COUNT; p++) {
+		if (ggzcore_player_has_perm(player, p)) {
+			snprintf(text + strlen(text),
+				 sizeof(text) - strlen(text),
+				 "%s\n", perm_name(p));
+		}
+	}
+	if (text[0] == '\0') {
+		snprintf(text, sizeof(text), _("none/unknown"));
+	} else {
+		text[strlen(text) - 1] = '\0';
+	}
+	gtk_label_set_text(GTK_LABEL(tmp), text);
+
 	/* The only thing we don't show is lag. */
 
 	if (ggzcore_player_get_record(player, &wins,
