@@ -3,7 +3,7 @@
  * Author: GGZ Dev Team
  * Project: GGZ GTK Client
  * Date: 11/03/2002
- * $Id: playerlist.c 7757 2006-01-09 18:03:06Z jdorje $
+ * $Id: playerlist.c 8771 2006-12-28 09:28:29Z jdorje $
  * 
  * List of players in the current room
  * 
@@ -36,6 +36,7 @@
 #include <ggzcore.h>
 
 #include "chat.h"
+#include "ggzutils.h"
 #include "playerinfo.h"
 #include "playerlist.h"
 #include "server.h"
@@ -60,7 +61,8 @@ static void client_player_info_activate(GtkMenuItem * menuitem, gpointer data)
 	player_info_create_or_raise(player);
 }
 
-static void client_player_friends_click(GtkMenuItem * menuitem, gpointer data)
+static void client_player_friends_activate(GtkMenuItem * menuitem,
+					   gpointer data)
 {
 	GGZPlayer *player = data;
 
@@ -70,7 +72,8 @@ static void client_player_friends_click(GtkMenuItem * menuitem, gpointer data)
 		chat_remove_friend(ggzcore_player_get_name(player));
 }
 
-static void client_player_ignore_click(GtkMenuItem * menuitem, gpointer data)
+static void client_player_ignore_activate(GtkMenuItem * menuitem,
+					  gpointer data)
 {
 	GGZPlayer *player = data;
 
@@ -80,23 +83,97 @@ static void client_player_ignore_click(GtkMenuItem * menuitem, gpointer data)
 		chat_remove_ignore(ggzcore_player_get_name(player));
 }
 
+static void client_player_kick_activate(GtkMenuItem * menuitem, gpointer data)
+{
+	GGZPlayer *player = data;
+
+	ggzcore_room_admin(ggzcore_server_get_cur_room(server),
+			   GGZ_ADMIN_KICK,
+			   ggzcore_player_get_name(player), NULL);
+}
+
+static void client_player_gag_activate(GtkMenuItem * menuitem, gpointer data)
+{
+	GGZPlayer *player = data;
+
+	ggzcore_room_admin(ggzcore_server_get_cur_room(server),
+			   GGZ_ADMIN_GAG,
+			   ggzcore_player_get_name(player), NULL);
+}
+
+static void client_player_ungag_activate(GtkMenuItem * menuitem, gpointer data)
+{
+	GGZPlayer *player = data;
+
+	ggzcore_room_admin(ggzcore_server_get_cur_room(server),
+			   GGZ_ADMIN_UNGAG,
+			   ggzcore_player_get_name(player), NULL);
+}
+
+static void client_player_ban_activate(GtkMenuItem * menuitem, gpointer data)
+{
+	/* TODO */
+}
+
+typedef struct {
+	GGZPlayer *player;
+	GGZPerm perm;
+} PermData;
+
+static void permdata_free(gpointer data, GClosure *closure)
+{
+	g_free(data);
+}
+
+static void client_player_perm_activate(GtkMenuItem * menuitem, gpointer data)
+{
+	PermData *pdata = data;
+	gboolean isset
+	  = gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(menuitem));
+
+	if (ggzcore_player_set_perm(pdata->player, pdata->perm, isset) < 0) {
+		chat_display_local(CHAT_LOCAL_NORMAL, NULL,
+				   _("Could not change permission."));
+	}
+}
+
+static bool is_admin(void)
+{
+	const char *handle = ggzcore_server_get_handle(server);
+	const GGZPlayer *player = ggzcore_server_get_player(server, handle);
+
+	if (player) {
+		GGZPlayerType type = ggzcore_player_get_type(player);
+
+		return (type == GGZ_PLAYER_HOST || type == GGZ_PLAYER_ADMIN);
+	} else {
+		return FALSE;
+	}
+}
+
 static GtkWidget *create_mnu_player(GGZPlayer *player, gboolean is_friend,
 				    gboolean is_ignore)
 {
 	GtkWidget *mnu_player;
 	GtkWidget *info;
-	GtkWidget *separator9;
+	GtkWidget *separator;
 	GtkWidget *friends;
 	GtkWidget *ignore;
+	GtkWidget *kick;
+	GtkWidget *gag;
+	GtkWidget *ungag;
+	GtkWidget *ban;
+	GtkWidget *perms[GGZ_PERM_COUNT];
+	GGZPerm p;
 
 	mnu_player = gtk_menu_new();
 
 	info = gtk_menu_item_new_with_label(_("Info"));
 	gtk_container_add(GTK_CONTAINER(mnu_player), info);
 
-	separator9 = gtk_menu_item_new();
-	gtk_container_add(GTK_CONTAINER(mnu_player), separator9);
-	gtk_widget_set_sensitive(separator9, FALSE);
+	separator = gtk_menu_item_new();
+	gtk_container_add(GTK_CONTAINER(mnu_player), separator);
+	gtk_widget_set_sensitive(separator, FALSE);
 
 	friends = gtk_check_menu_item_new_with_label(_("Friends"));
 	gtk_container_add(GTK_CONTAINER(mnu_player), friends);
@@ -108,14 +185,71 @@ static GtkWidget *create_mnu_player(GGZPlayer *player, gboolean is_friend,
 	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(ignore),
 				       is_ignore);
 
+	separator = gtk_menu_item_new();
+	gtk_container_add(GTK_CONTAINER(mnu_player), separator);
+	gtk_widget_set_sensitive(separator, FALSE);
+
+	kick = gtk_menu_item_new_with_label(_("Kick player"));
+	gtk_container_add(GTK_CONTAINER(mnu_player), kick);
+	gtk_widget_set_sensitive(kick, is_admin());
+
+	gag = gtk_menu_item_new_with_label(_("Gag player"));
+	gtk_container_add(GTK_CONTAINER(mnu_player), gag);
+	gtk_widget_set_sensitive(gag, is_admin());
+
+	ungag = gtk_menu_item_new_with_label(_("Ungag player"));
+	gtk_container_add(GTK_CONTAINER(mnu_player), ungag);
+	gtk_widget_set_sensitive(ungag, is_admin());
+
+	ban = gtk_menu_item_new_with_label(_("Ban player"));
+	gtk_container_add(GTK_CONTAINER(mnu_player), ban);
+	gtk_widget_set_sensitive(ban, FALSE);
+
+	separator = gtk_menu_item_new();
+	gtk_container_add(GTK_CONTAINER(mnu_player), separator);
+	gtk_widget_set_sensitive(separator, FALSE);
+
+	for (p = 0; p < GGZ_PERM_COUNT; p++) {
+		const char *name = perm_name(p);
+		bool isset = ggzcore_player_has_perm(player, p);
+		PermData *pdata = g_malloc(sizeof(*pdata));
+
+		if (name == NULL) continue;
+		perms[p] = gtk_check_menu_item_new_with_label(name);
+
+		gtk_container_add(GTK_CONTAINER(mnu_player), perms[p]);
+		gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(perms[p]),
+					       isset);
+		gtk_widget_set_sensitive(perms[p], is_admin());
+
+		pdata->player = player;
+		pdata->perm = p;
+
+		g_signal_connect_data(GTK_OBJECT(perms[p]), "activate",
+			GTK_SIGNAL_FUNC(client_player_perm_activate),
+			pdata, permdata_free, 0);
+	}
+
 	g_signal_connect(GTK_OBJECT(info), "activate",
 			 GTK_SIGNAL_FUNC(client_player_info_activate),
 			 player);
 	g_signal_connect(GTK_OBJECT(friends), "activate",
-			 GTK_SIGNAL_FUNC(client_player_friends_click),
+			 GTK_SIGNAL_FUNC(client_player_friends_activate),
 			 player);
 	g_signal_connect(GTK_OBJECT(ignore), "activate",
-			 GTK_SIGNAL_FUNC(client_player_ignore_click),
+			 GTK_SIGNAL_FUNC(client_player_ignore_activate),
+			 player);
+	g_signal_connect(GTK_OBJECT(kick), "activate",
+			 GTK_SIGNAL_FUNC(client_player_kick_activate),
+			 player);
+	g_signal_connect(GTK_OBJECT(gag), "activate",
+			 GTK_SIGNAL_FUNC(client_player_gag_activate),
+			 player);
+	g_signal_connect(GTK_OBJECT(ungag), "activate",
+			 GTK_SIGNAL_FUNC(client_player_ungag_activate),
+			 player);
+	g_signal_connect(GTK_OBJECT(ban), "activate",
+			 GTK_SIGNAL_FUNC(client_player_ban_activate),
 			 player);
 
 	return mnu_player;
@@ -137,6 +271,7 @@ static gboolean player_list_event(GtkWidget *widget,
 					   &path, NULL, NULL, NULL)) {
 		return FALSE;
 	}
+	/* FIXME: must free path variable? */
 	gtk_tree_model_get_iter(model, &iter, path);
 
 	gtk_tree_model_get(model, &iter, PLAYER_COLUMN_NAME, &name, -1);
@@ -171,7 +306,7 @@ void sensitize_player_list(gboolean sensitive)
 /* Clear current list of players */
 void clear_player_list(void)
 {
-	GtkWidget *store = lookup_widget(player_list, "player_list_store");
+	GtkWidget *store = ggz_lookup_widget(player_list, "player_list_store");
 
         gtk_list_store_clear(GTK_LIST_STORE(store));
 }
@@ -193,7 +328,7 @@ void update_player_list(void)
 	char stats[512];
 
 	/* Retrieve the player list widget. */
-	store = GTK_LIST_STORE(lookup_widget(player_list,
+	store = GTK_LIST_STORE(ggz_lookup_widget(player_list,
 					     "player_list_store"));
 
 	/* Clear current list of players */
@@ -284,6 +419,7 @@ void update_player_list(void)
 			gtk_list_store_set(store, &iter,
 					   PLAYER_COLUMN_TYPE, registered, -1);
 			break;
+		case GGZ_PLAYER_HOST:
 		case GGZ_PLAYER_ADMIN:
 			gtk_list_store_set(store, &iter,
 					   PLAYER_COLUMN_TYPE, admin, -1);
@@ -300,6 +436,17 @@ void update_player_list(void)
 	}
 }
 
+static gint player_sort_func(GtkTreeModel *model,
+			   GtkTreeIter *a, GtkTreeIter *b, gpointer data)
+{
+	char *nameA, *nameB;
+
+	gtk_tree_model_get(model, a, PLAYER_COLUMN_NAME, &nameA, -1);
+	gtk_tree_model_get(model, b, PLAYER_COLUMN_NAME, &nameB, -1);
+
+	return (strcasecmp(nameA, nameB));
+}
+
 GtkWidget *create_player_list(GtkWidget *parent)
 {
 	GtkListStore *store;
@@ -317,6 +464,14 @@ GtkWidget *create_player_list(GtkWidget *parent)
 	tree = gtk_tree_view_new_with_model(GTK_TREE_MODEL(store));
 	g_object_unref(store);
 
+	gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(store),
+					     PLAYER_COLUMN_NAME,
+					     GTK_SORT_ASCENDING);
+	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store),
+					PLAYER_COLUMN_NAME,
+					player_sort_func,
+					NULL, NULL);
+
 	renderer = gtk_cell_renderer_pixbuf_new();
 	column = gtk_tree_view_column_new_with_attributes("", renderer,
 				"pixbuf", PLAYER_COLUMN_TYPE, NULL);
