@@ -2,7 +2,7 @@
  * File: support.c
  * Author: Justin Zaun
  * Project: GGZ GTK Client
- * $Id: support.c 7204 2005-05-21 09:31:23Z josef $
+ * $Id: support.c 8180 2006-06-12 21:56:56Z jdorje $
  *
  * Support code
  *
@@ -45,10 +45,13 @@
 #include "props.h"
 #include "support.h"
 
-GtkWidget *lookup_widget(GtkWidget * widget, const gchar * widget_name)
+GtkWidget *ggz_lookup_widget(GtkWidget * widget, const gchar * widget_name)
 {
 	GtkWidget *parent, *found_widget;
 
+	found_widget = g_object_get_data(G_OBJECT(widget), widget_name);
+	if (found_widget) return found_widget;
+
 	for (;;) {
 		if (GTK_IS_MENU(widget))
 			parent =
@@ -72,7 +75,7 @@ GdkPixbuf *load_pixbuf(const char *name)
 	GdkPixbuf *image;
 	GError *error = NULL;
 
-	fullpath = g_strdup_printf("%s/%s.png", GGZDATADIR, name);
+	fullpath = g_strdup_printf("%s/%s.png", GGZGTKDATADIR, name);
 	image = gdk_pixbuf_new_from_file(fullpath, &error);
 	if (image == NULL) {
 		ggz_error_msg("Can't load pixmap %s", fullpath);
@@ -89,7 +92,7 @@ GdkPixbuf *load_svg_pixbuf(const char *name, int width, int height)
 	GdkPixbuf *image;
 	GError *error = NULL;
 
-	fullpath = g_strdup_printf("%s/%s.svg", GGZDATADIR, name);
+	fullpath = g_strdup_printf("%s/%s.svg", GGZGTKDATADIR, name);
 	image = gdk_pixbuf_new_from_file_at_size(fullpath,
 						 width, height,
 						 &error);
